Name: osiris
Version: 4.2.3
Release: 1
Group: System Environment/Daemons
Packager: Jason Frisvold <friz@godshell.com>
Vendor: Brian Wotring <brian@shmoo.com>
Copyright: Osiris Software License, Version 1.3
URL: http://www.hostintegrity.com
Summary: Host Integrity Monitoring Server
Provides: osiris
BuildRoot: %{_tmppath}/%{name}-%{version}
Source0: http://www.hostintegrity.com/osiris/data/osiris-%{version}.tar.gz
Source1: http://www.hostintegrity.com/osiris/data/modules/mod_uptime.tar.gz
Source2: http://www.hostintegrity.com/osiris/data/modules/mod_dns.tar.gz
Source3: http://www.hostintegrity.com/osiris/data/modules/mod_nvram.tar.gz
Source4: http://www.hostintegrity.com/osiris/data/modules/mod_ports.tar.gz
Source5: http://www.hostintegrity.com/osiris/data/modules/mod_if.tar.gz
Source6: http://www.hostintegrity.com/osiris/data/modules/mod_rpm.tar.gz
%define osiris_user osiris
%define osiris_home %{_localstatedir}/lib/osiris

%description
Osiris is a Host Integrity Management System that periodically
monitors one or more hosts for change. It maintains detailed
logs of changes to the file system, user and group lists,
resident kernel modules, and more. Osiris can be configured to
email these logs to the administrator. Hosts are periodically
scanned and, if desired, the records can be maintained for
forensic purposes. Osiris keeps an administrator apprised of
possible attacks and/or nasty little trojans. The purpose here
is to isolate changes that indicate a break-in or a compromised
system. Osiris makes use of OpenSSL for encryption and
authentication in all components.

This package contains the server programs.

%prep
%setup -q -a1 -c -n %{name}-%{version}/src/osirisd/modules
%setup -q -D -T -a2 -n %{name}-%{version}/src/osirisd/modules
%setup -q -D -T -a4 -n %{name}-%{version}/src/osirisd/modules
%setup -q -D -T -a5 -n %{name}-%{version}/src/osirisd/modules
%setup -q -D -T -a6 -n %{name}-%{version}/src/osirisd/modules
%setup -q -D -T -b0 -n %{name}-%{version}

%build
%configure \
%if %{!?_without_fancycli:1}%{?_without_fancycli:0}
   --enable-fancy-cli \
%endif
   --with-root-dir=%{osiris_home} \
   --with-osiris-user=%{osiris_user}
make

%install
rm -fr %{buildroot}
make DESTDIR=%{buildroot} install

%clean
rm -fr %{buildroot}

%pre
id %{osiris_user} > /dev/null 2>&1 || \
   /usr/sbin/useradd -u 300 -r -d %{osiris_home} -s /sbin/nologin \
   -c "Osiris Daemon" %{osiris_user}
if [ ! -d %{osiris_home} ]; then
   mkdir -p %{osiris_home}
   chown %{osiris_user}.%{osiris_user} %{osiris_home}
   chmod 2750 %{osiris_home}
fi

%post
/sbin/chkconfig --add osirismd
/sbin/service osirismd start > /dev/null 2>&1

%preun
if [ "$1" = 0 ]; then
  /sbin/service osirismd stop > /dev/null 2>&1
  /sbin/chkconfig --del osirismd
fi

%postun
if [ "$1" -ge "1" ]; then
   /sbin/service osirismd condrestart > /dev/null 2>&1
else
   /usr/sbin/userdel %{osiris_user} 2>&1 || :
fi

# --with-mgmt-pkg - This will create a seperate management console package
%if %{?_with_mgmtpkg:1}%{!?_with_mgmtpkg:0}

%files
%defattr(-, root, wheel, 0755)
%doc %attr(644, root, root)LICENSE NEWS TODO README AUTHORS ChangeLog COPYING
%dir %attr(2750, %{osiris_user}, %{osiris_user}) %{_localstatedir}/lib/osiris
%dir %attr(2750, %{osiris_user}, %{osiris_user}) %{_localstatedir}/lib/osiris/configs
%config %attr(640, %{osiris_user}, %{osiris_user}) %{_localstatedir}/lib/osiris/configs/*
%attr(755, root, root)%{_sysconfdir}/rc.d/init.d/osirismd
%attr(4755, %{osiris_user}, %{osiris_user})%{_sbindir}/osirismd

%package mgmtconsole
Group: System Environment/Daemons
Summary: Host Integrity Monitoring Client

%description mgmtconsole
Osiris is a Host Integrity Management System that periodically
monitors one or more hosts for change. It maintains detailed
logs of changes to the file system, user and group lists,
resident kernel modules, and more.

This package contains the command line interface.

%files mgmtconsole
%defattr(-, root, wheel, 0755)
%doc %attr(644, root, root)LICENSE NEWS TODO README AUTHORS ChangeLog COPYING
%{_sbindir}/osiris

%else

%files
%defattr(-, root, wheel, 0755)
%doc %attr(644, root, root)LICENSE NEWS TODO README AUTHORS ChangeLog COPYING
%{_sbindir}/osiris
%dir %attr(2750, %{osiris_user}, %{osiris_user}) %{_localstatedir}/lib/osiris
%dir %attr(2750, %{osiris_user}, %{osiris_user}) %{_localstatedir}/lib/osiris/configs
%config %attr(640, %{osiris_user}, %{osiris_user}) %{_localstatedir}/lib/osiris/configs/*
%attr(755, root, root)%{_sysconfdir}/rc.d/init.d/osirismd
%attr(4755, %{osiris_user}, %{osiris_user})%{_sbindir}/osirismd

%endif

%package client
Group: System Environment/Daemons
Summary: Host Integrity Monitoring Client

%description client
Osiris is a Host Integrity Management System that periodically
monitors one or more hosts for change. It maintains detailed
logs of changes to the file system, user and group lists,
resident kernel modules, and more.

This package contains the client programs.

%pre client
id %{osiris_user} > /dev/null 2>&1 || \
   /usr/sbin/useradd -u 300 -r -d %{osiris_home} -s /sbin/nologin \
   -c "Osiris Daemon" %{osiris_user}
if [ ! -d %{osiris_home} ]; then
   mkdir -p %{osiris_home}
   chown %{osiris_user}.%{osiris_user} %{osiris_home}
   chmod 2750 %{osiris_home}
fi

%post client
/sbin/chkconfig --add osirisd
/sbin/service osirisd start > /dev/null 2>&1

%preun client
if [ "$1" = 0 ]; then
   /sbin/service osirisd stop > /dev/null 2>&1
   /sbin/chkconfig --del osirisd
fi

%postun client
if [ "$1" -ge "1" ]; then
   /sbin/service osirisd condrestart > /dev/null 2>&1
else
   /usr/sbin/userdel %{osiris_user} 2>&1 || :
fi

%files client
%doc %attr(644, root, root)LICENSE NEWS TODO README AUTHORS ChangeLog COPYING
%attr(755, root, root)%{_sysconfdir}/rc.d/init.d/osirisd
%attr(755, root, root)%{_sbindir}/osirisd

%changelog
* Mon Jan 22 2007 Jason Frisvold <friz@godshell.com> 4.2.3-1
- FIXES:
- 
- : Windows uninstaller now removes all osiris related registry
-   keys during uninstall.
- : Linux mod_ports will only attempt to process the tcp
-   procfiles if they exist.
- : Fixed a bug in the osirismd where the scan context was
-   closed too early in the compare routine.
- : Fixed a bug in the CLI where print-db would see a race
-   condition and fail.
- : Fixed the console and agent creation scripts to build the
-   OpenBSD packages correctly.
- : Lemmings provided a fix to clean up defunct processes being
-   created by the osirismd scheduling process.
- 
- FEATURES:
- 
- : Filters are now stored in a flat text file on the management
-   daemon.  Existing filters will be copied from the filter
-   database into the flat text file if the flat file does not
-   exist at the time of osirismd starting.  This allows the
-   filters to keep their order and makes comments in the filters
-   much more useful.

* Fri Sep 19 2006 Jason Frisvold <friz@godshell.com> 4.2.2-1
- FIXES:
- 
- : Modified md_scan to push the base database before reading
-   the host.  This fixes the problem where a host is unable
-   to be scanned the first time after it loses its session key.
- : Fixed the version.h version string so make console and
-   make agent would correctly build the tarballs.
- : Fixed create_console.sh and create_agent.sh to be compatible
-   with older uname versions.
- : Fixed format string vulnerabilities in the logging functions
-   for windows based scan agents.
- 
- FEATURES:
- 
- : Added functionality to the CLI to allow print-db without
-   having the host active (print-db <hostname> <db number>)
- : Modified mod_ports to allow the filtering by uid.  Updated
-   the README in the mod_ports directory to document how
-   filtering works.
- : Added in the mod_if module to the main distribution.

* Fri Jul 28 2006 Jason Frisvold <friz@godshell.com> 4.2.1-1
- SECURITY : Fix for CVE-2006-3120

* Mon Feb 20 2006 Jason Frisvold <friz@godshell.com> 4.2.0-3
- Update to Release Version

* Tue Dec 20 2005 Jason Frisvold <friz@godshell.com> 4.2.0-2
- Update to RC-2
- Web authentication fix

* Sat Dec 10 2005 Jason Frisvold <friz@godshell.com> 4.2.0-1
- Update to RC-1
- mod_if updated to latest version
- mod_rpm added
-
- FIXES:
- 
- - scanner adheres to new Mac OS X resource fork convention.
- - fixed bug with readdir() wrapper bug with dirents end case.
- - fixed Date header in email notifications for console on Windows.
- - updated linux init script installs.
- - fixed bug with add/remove user on same login session.
- - removed uid/inode from linux mod_ports record header.
- - fixed potential problem with deep paths in scanner.
- 
- FEATURES:
- 
- - scan command now pushes baseline database to host.
- - added import-filters command (developer submission).
- - auth.db passwords are now encrypted (hashed).
- - mod_ports has new params to ignore certain port numbers.
- - added -q option to console, to not log to system log.

* Sun Sep 25 2005 Jason Frisvold <friz@godshell.com> 4.1.9-2
* Added mod_if

* Sun Sep  4 2005 Jason Frisvold <friz@godshell.com> 4.1.9-1
- Updated to 4.1.8
- Updated to latest mod_ports and mod_dns
- FIXES:
-
- - fixed install.sh to get proper ROOT_GROUP for Linux.
- - added runlevel 2 to linux init script setup.
- - added informative error messages in cli for init command.
- - fixed filter bug where notifications sent on zero changes.
- - fixed notify bug where SMTP buffer not large enough for some mailers.
- - fixed missing test-filter alias (test-regex).
- - fixed bug with root path not being assumed from command line arguments.
- - fixed installer for linux distro detection command.
- - fixed bug with info/error/warn message headers not being filtered
- correctly.
-
- FEATURES:
-
- - mod_ports for linux now supports monitoring/reporting on inode and uid.

* Fri Apr 22 2005 Jason Frisvold <friz@godshell.com> 4.1.8-2
- Added --with mgmtpkg option to split into 3 packages
- - Requested by Jamie Wilkinson (jaq@spacepants.org)

* Fri Apr 22 2005 Jason Frisvold <friz@godshell.com> 4.1.8-1
- Updated to 4.1.8
- FIXES:
-
- - added contraints to -p (port) argument to scan agent, accepts
-   numbers only (agent).
- - added arguments for pid file specification to fix various init
-   scripts and ports (agent/console).
- - fixed conflicts with fancy-cli and readline options.
- - fixed minor bug with CLI not interpreting host argument correctly. 

* Sun Apr 10 2005 Jason Frisvold <friz@godshell.com> 4.1.7-1
- Updated to 4.1.7
- FIXES:
-
- - fixed typos in CLI interface.
- - removed borked filter wizard option.
- - changed errors to warnings for checks on editor executable in CLI.
- - editor searching now will make use of PATH env variable.
- - filters editing now works; uses editor, not a stupid menu.
-
- FEATURES:
-
- - UNIX installer can initiate non-interactive install via command line argument.
- - added mass deployment perl script for adding agents to management console.
- - added unset-base-db command to CLI.
- - added copy configuration command (cp-config).
- - added readline support (link against libreadline if installed). 

* Sat Mar 26 2005 Jason Frisvold <friz@godshell.com> 4.1.5-1
- Updated to 4.1.5
- FIXES:
-
- - certificate pre-provisioning for Windows installer now works.
- - http port no longer on by default.
- - removed -u argument from CLI, it was useless.
- - fixed bug with Solaris x86 mod_kmods not working at all.
-
- FEATURES:
-
- - CLI now supports argument to specify remote port (-p).

* Mon Mar 21 2005 Jason Frisvold <friz@godshell.com> 4.1.4-1
- Updated to 4.1.4
- FIXES:
-
- - fixed bug in solaris init script, for stop osirismd (didn't work).
- - fixed annoying warning in installer for backing up default configs.
- - removed gcc dependancy in modules Makefile.am
- - removed stray C++ style comments from regex library.
- - fixed configure problem determination of -Wall flag use (portability issue).
- - fixed osirsimd freebsd init script, missing rc command..
- - fixed bug with files_scanned counter always zero in db header.
- - added error logging to file checksumming code.
- - fixed bug with windows time zone offset not being used in notify date headers.
-
- FEATURES:
-
- - added quiet option (-q) to scan agent; produces no local logging.

* Sun Feb 27 2005 Jason Frisvold <friz@godshell.com> 4.1.3-1
- Updated to 4.1.3
- FIXES:
-
- - fixed mod_ports record key value so address is included, as port
-   number may not be unique in the case of  multiple interfaces.
- - fixed minor bug in gentoo installation, relative path to rc-update.
- - Date header for mail, and others now compliant with rfc2822.
- - debian init script improperly used chuid option on agent.
- - fixed bug with filters still generating email notifications.
-
- FEATURES:
-
- - added Linux support for native mod_ports module (experimental).

* Fri Feb 11 2005 Jason Frisvold <friz@godshell.com> 4.1.2-1
- Updated to 4.1.2
- FIXES:
- - fixed notification email bug with url not being added to email.
- - fixed http_host field not being used for log reports URLs.

* Sat Jan 29 2005 Jason Frisvold <friz@godshell.com> 4.1.1-3
- Added a patch to fix another bug in the notify function

* Fri Jan 28 2005 Jason Frisvold <friz@godshell.com> 4.1.1-2
- Added a patch to fix the notify function

* Thu Jan 27 2005 Jason Frisvold <friz@godshell.com> 4.1.1-1
- Updated to 4.1.1
- FEATURES:
- - added mod_ports for Windows XP.  Open network port monitoring module.
- FIXES:
- - fixed email subject heading not being set correctly for log notifications.
- Added mod_ports to the rpm
- Updated mod_dns to the latest version

* Tue Jan 11 2005 Jason Frisvold <friz@godshell.com> 4.0.8-1
- Updated to 4.0.8
- FIXED:
- - updated copyrights.
- FEATURES:
- - port of host.conf config keyword from the 4.1 branch.

* Fri Dec 31 2004 Jason Frisvold <friz@godshell.com> 4.0.7-2
- mod_uptime and mod_dns have been added
- mod_nvram is added as a source to include it in the SRPM package

* Fri Dec 31 2004 Jason Frisvold <friz@godshell.com> 4.0.7-1
- Updated to 4.0.7
- FIXED:
- - cli stat of editor incorrect.
- - utilities.c, escape filename bug in octal handling.
- - fixed memory leak in regex file filter hs_regfree missing.

* Mon Nov 8 2004 Jason Frisvold <friz@godshell.com> 4.0.6-1
- Updated to 4.0.6
- FIXED:
- - typo in generic osirismd rc script.
- - changed verify cert depth to 10, from 4.
- - moved 'continue' prompt to beginning of installer, where it should be.
- - fixed regular expression filter value bug with parens.
- FEATURES:
- - added default config for Linksys WRT54G(S).
- - changed notification subject lines for easier parsing.

* Mon Sep 27 2004 Jason Frisvold <friz@godshell.com> 4.0.5-2
- Updated to 4.0.5
- FIXED:
- - configuration bug, NoEntry directive on "/" block not working correctly.

* Wed Sep 22 2004 Jason Frisvold <friz@godshell.com> 4.0.5-1
- Updated to 4.0.5-rc1
- FIXED:
- - url now not shown in notification emails when auto-accept turned on.
- - removed "checking schedules" log from windows builds.
- - bug with test-notify message headers, extra crlf.
- - fixed timezone problem with scheduler prompt (thanks spike!)
- - bug with non-privsep unix platforms unresolve rootpriv_fopen calls.
- - configure script, no -Wall option for AIX compiler.
- - removed C++ style comments from common code.
- - fixed bugs with installer on irix for user/group creation.
- - fixed bug with windows installer not properly shutting down existing services.
- - windows kmod status field now a word/description, not just a number.
- - bug with print-config not always printing config name.
- FEATURES:
- - admin email to management config.  when set, this will send ALL mail notifications to this address in addition to any other set email addresses.

* Tue Jun 22 2004 Jason Frisvold <friz@godshell.com> 4.0.3-1
- Updated to 4.0.3

* Tue May 25 2004 Jason Frisvold <friz@godshell.com> 4.0.2-2
- Added patch to fix goofy redhat grep problem on RHES 3.0

* Tue May 18 2004 Jason Frisvold <friz@godshell.com> 4.0.2-1
- Upped to 4.0.2 Release Candidate

* Wed May 12 2004 Jason Frisvold <friz@godshell.com> 4.0.1-4
- Fixed a problem with emails not having a newline between the subject and the body.  This caused qmail-scanner to tag the mail as bad.

* Mon May 10 2004 Jason Frisvold <friz@godshell.com> 4.0.1-3
- 4.0.1 Release version

* Wed May 5 2004 Jason Frisvold <friz@godshell.com> 4.0.1-2
- Added fancy cli option - Can disable on build with --without fancycli

* Tue May 4 2004 Jason Frisvold <friz@godshell.com> 4.0.1-1
- 4.0.1 Release Candidate 2

* Mon Apr 26 2004 Jason Frisvold <friz@godshell.com> 4.0.0-1
- Upped to release version
- Removed beta patches (rolled into release)
- Redhat init scripts were rolled into the release as well

* Thu Apr 8 2004 Jason Frisvold <friz@godshell.com> 4.0.0-beta-5
- Working on an authentication problem with Brian, added code to
  print out the OpenSSL authentication failure reasons.
- Further defining the scripts to prevent unecessary errors

* Thu Apr 8 2004 Jason Frisvold <friz@godshell.com> 4.0.0-beta-4
- Added patch for missed include in debug.c

* Wed Apr 7 2004 Jason Frisvold <friz@godshell.com> 4.0.0-beta-3
- More bugfixes in the scripting section of the rpm
- Permissions updated as well
- Also separated the server from the client.

* Tue Apr 6 2004 Jason Frisvold <friz@godshell.com> 4.0.0-beta-2
- Bugfixes in the scripting section of the rpm

* Tue Apr 6 2004 Jason Frisvold <friz@godshell.com> 4.0.0-beta-1
- Initial RPM build
- Original specfile, Makefile changes, and redhat init scripts
  by osiris@lemmin.gs
